==> haskell-lsp-test-0.14.1.0-93-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.1.0
visibility:           public
id:                   lsp-test-0.14.1.0-9u6qYlQ18gELHEpcL2bTdZ
key:                  lsp-test-0.14.1.0-9u6qYlQ18gELHEpcL2bTdZ
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  6e789a2604484de12ef8a590a01e1942
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.6.0.0-2bofF1fRSsb5ddfkj3rDHp:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.6.0.0-2bofF1fRSsb5ddfkj3rDHp:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.1.0-9u6qYlQ18gELHEpcL2bTdZ
depends:
    Diff-0.4.1-2b84kELbdFiFT3I48y9pel
    Glob-0.10.2-1KcEJJNRbdsLtV0wRk55uc
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    aeson-pretty-0.8.10-7367jfN5uCWGVYHo3rguZr
    ansi-terminal-0.11.4-6jSb6ZqnQv5806EReMBETJ
    async-2.2.5-b1lsUdcpsoF4yB7f3qI00 base-4.16.4.0 bytestring-0.11.4.0
    co-log-core-0.3.2.1-It8qfPnPtZf5KV2MO88VWA
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-parse-0.2.1.1-LQweAc5dOs8KiNGkaXkcwh containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ
    lsp-types-1.6.0.0-2bofF1fRSsb5ddfkj3rDHp mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 process-1.6.16.0
    some-1.0.5-L5glA67mR8RJufLDsA2lRz text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.14.1.0-114-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.1.0
visibility:           public
id:                   lsp-test-0.14.1.0-HSIEH7YdoXhJqpfs8HSsWa
key:                  lsp-test-0.14.1.0-HSIEH7YdoXhJqpfs8HSsWa
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  a1346f45a71d7b61abc32df7216aa559
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-test-0.14.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.14.1.0-HSIEH7YdoXhJqpfs8HSsWa
depends:
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    Glob-0.10.2-JVeFEC6qqQ64Hty45Py8El
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-pretty-0.8.10-3gMGTHlvRlNFcX72WIXlCa
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 co-log-core-0.3.2.2-JkIBrl3CmC2ATtyDHDAqqi
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-parse-0.2.1.1-22oidjwb8Jj2NfoqWGmWpb containers-0.6.5.1
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO
    lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb mtl-2.2.2
    parser-combinators-1.3.0-G0J7GFw9FY9Cgw8HeD2oK5 process-1.6.16.0
    some-1.0.5-L5glA67mR8RJufLDsA2lRz text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
